@@ -13,9 +13,11 @@ class editor():
         cur = self.con.cursor()
         cur.execute(f"DROP TABLE IF EXISTS {tablename}")
         cur.execute(f"CREATE TABLE {tablename} ()")
-        if kwargs != None:
+        try:
             for row in kwargs["rows"]:
                 cur.execute(f"ALTER TABLE {tablename} ADD COLUMN {row}")
+        except:
+            pass
         self.con.commit()
 
     def drop_table(self, tablename):
